@@ -44,17 +44,20 @@
 #'
 #' @details
 #'
-#' Different steps of a design may each be simulated different a number of times, as specified by sims. In this case simulations are grouped into "fans", eg "fan_1" indicates all the simulations that have the same draw from the first level of the design. For efficiency there are generally fewer fans than design steps where all contiguous steps with 1 sim specified are combined into a single fan.
+#' Different steps of a design may each be simulated different a number of times, as specified by sims. In this case simulations are grouped into "fans". The nested 
+#' structure of simulations is recorded in the dataset using a set of variables named "step_x_draw." For example if sims = c(2,1,1,3) is passed to simulate_design, then there
+#' will be two distinct draws of step 1, indicated in variable "step_1_draw" (with values 1 and 2) and there will be three draws for step 4 within each of the step 1 draws, recorded in "step_4_draw" (with values 1 to 6).
+#'    
 simulate_design <- function(..., sims = 500) {
   designs <- dots_to_list_of_designs(...)
-
+  
   # if you provide a list of sims for each design, i.e.
   #   sims = list(my_design_1 = c(100, 1, 1), my_design_2 = 200)
   # use it! otherwise, create a list of length designs that repeats the sims
   if (!is_list(sims)) {
     sims <- lapply(seq_along(designs), function(i) sims)
   }
-
+  
   # Simulate One or More Designs
   simulations_list <- mapply(
     design = designs,
@@ -62,15 +65,15 @@ simulate_design <- function(..., sims = 500) {
     FUN = simulate_single_design,
     SIMPLIFY = FALSE
   )
-
+  
   simulations_list <- Map(cbind, design_label = names(simulations_list), simulations_list, stringsAsFactors = FALSE)
-
+  
   # Cleanup
   simulations_df <- rbind_disjoint(simulations_list)
   rownames(simulations_df) <- NULL
-
+  
   # Obtain all parameters
-
+  
   parameters_df_list <- lapply(designs, function(x) attr(x, "parameters"))
   parameters_df_list <- lapply(seq_along(parameters_df_list), function(i) {
     out <- data.frame(design_label = names(parameters_df_list[i]))
@@ -81,26 +84,32 @@ simulate_design <- function(..., sims = 500) {
   })
   parameters_df <- rbind_disjoint(parameters_df_list)
   parameters_df <- data.frame(lapply(parameters_df, type_convert), stringsAsFactors = FALSE)
-
+  
   simulations_df <- simulations_df[, reorder_columns(parameters_df, simulations_df), drop = FALSE]
-
+  
   attr(simulations_df, "parameters") <- parameters_df
-
+  
   simulations_df
 }
 
+#' @rdname simulate_design
+#' @export
+simulate_designs <- simulate_design
+
+
 
 #' @importFrom rlang as_list
 simulate_single_design <- function(design, sims) {
   if (!is_bare_integerish(sims) || (length(design) != length(sims) & length(sims) != 1)) {
     stop("Please provide sims a scalar or a numeric vector of length the number of steps in designs.", call. = FALSE)
   }
-
+  
   if (min(sims) < 1) {
     stop("Sims should be >= 1", call. = FALSE)
   }
-
-  if (length(sims) > 1 && sims[1] < 30) {
+  
+  # See also ?testthat::is_testing
+  if (sims[1] < 30 && !identical(Sys.getenv("TESTTHAT"), "true")) {
     warning(
       "We recommend you choose a higher number of simulations than ",
       sims[1],
@@ -108,46 +117,78 @@ simulate_single_design <- function(design, sims) {
       call. = FALSE
     )
   }
-
+  
+  # escape hatch for all ones
+  if(prod(sims) == 1) sims <- 1
+  
   # If sims is set correctly, fan out
-
+  
   if (length(sims) == 1 && is.null(names(sims))) {
     results_list <- future_lapply(seq_len(sims),
-      function(i)
-        run_design(design),
-      future.seed = NA, future.globals = "design"
+                                  function(i)
+                                    run_design(design),
+                                  future.seed = NA, future.globals = "design"
     )
   } else {
     sims <- check_sims(design, sims)
     results_list <- fan_out(design, sims)
-    fan_id <- setNames(
-      lapply(rev(sims$n), seq),
-      paste0("fan_", seq_len(nrow(sims)))
-    )
-    fan_id <- expand.grid(fan_id)
-    fan_id$sim_ID <- seq_len(nrow(fan_id))
+    
+    
+    
   }
-
+  
   results2x <- function(results_list, what) {
     subresult <- lapply(results_list, `[[`, what)
     df <- do.call(rbind.data.frame, subresult)
     if (nrow(df) == 0) {
       return(df)
     }
-
+    
     df <- cbind(sim_ID = rep(seq_along(subresult), vapply(subresult, nrow, 0L)), df)
   }
-
+  
   estimates_df <- results2x(results_list, "estimates_df")
   estimands_df <- results2x(results_list, "estimands_df")
-
+  
   if (is_empty(estimates_df) && is_empty(estimands_df)) {
     stop("No estimates or estimands were declared, so design cannot be simulated.", call. = FALSE)
   } else if (is_empty(estimands_df)) {
     simulations_df <- estimates_df
   } else if (is_empty(estimates_df)) {
     simulations_df <- estimands_df
+  } else if (all(estimands_df$estimand_label %in% estimates_df$estimand_label) &
+             all(estimates_df$estimand_label %in% estimands_df$estimand_label)){
+    
+    
+    estimands_df_split <- split(x = estimands_df, f = estimands_df$estimand_label)
+    estimates_df_split <- split(x = estimates_df, f = estimates_df$estimand_label)
+    
+    non_missing_columns <- function(dat){
+      nonmissing <- apply(dat, 2, FUN = function(x) any(!is.na(x)))
+      return(dat[,nonmissing,drop = FALSE])
+    }
+    
+    
+    estimands_df_split <- lapply(estimands_df_split, non_missing_columns)
+    estimates_df_split <- lapply(estimates_df_split, non_missing_columns)
+    
+    by_split <- lapply(X = seq_along(estimands_df_split), 
+                       FUN = function(x){
+                         colnames(estimands_df_split[[x]]) %icn% estimates_df_split[[x]]
+                       })
+    
+    simulations_df_split <- 
+      mapply(FUN = merge,
+             x = estimands_df_split,
+             y = estimates_df_split,
+             by = by_split,
+             MoreArgs = list(all = TRUE, sort = FALSE),
+             SIMPLIFY = FALSE
+      )
+    
+    simulations_df <- rbind_disjoint(simulations_df_split)
   } else {
+    
     simulations_df <- merge(
       estimands_df,
       estimates_df,
@@ -155,27 +196,24 @@ simulate_single_design <- function(design, sims) {
       all = TRUE,
       sort = FALSE
     )
-
+    
     if (nrow(simulations_df) > max(nrow(estimands_df), nrow(estimates_df))) {
       warning(
         "Estimators lack estimand/term labels for matching, a many-to-many merge was performed."
       )
     }
   }
-
-  if (exists("fan_id")) {
-    simulations_df <- merge(simulations_df, fan_id, by = "sim_ID")
-  }
-
+  
   if (!is_empty(attr(design, "parameters"))) {
     simulations_df <-
       data.frame(
         simulations_df[, 1, drop = FALSE],
         as_list(attr(design, "parameters")),
-        simulations_df[, -1, drop = FALSE]
+        simulations_df[, -1, drop = FALSE], 
+        stringsAsFactors = FALSE
       )
   }
-
+  simulations_df <- data.frame(lapply(simulations_df, type_convert), stringsAsFactors = FALSE)
   simulations_df
 }
 
@@ -183,26 +221,26 @@ simulate_single_design <- function(design, sims) {
 #' @importFrom rlang quo_squash is_call
 infer_names <- function(x, type = "design") {
   inferred_names <- names(x) %||% rep("", length(x))
-
+  
   inferred_names <- vapply(seq_along(x),
-    FUN.VALUE = "",
-    function(i, xi = x[[i]], nm = inferred_names[i]) {
-      if (nm != "") {
-        nm
-      } else if (!is_quosure(xi) || is_call(quo_squash(xi))) {
-        paste0(type, "_", i)
-      } else {
-        quo_text(xi)
-      }
-    }
+                           FUN.VALUE = "",
+                           function(i, xi = x[[i]], nm = inferred_names[i]) {
+                             if (nm != "") {
+                               nm
+                             } else if (!is_quosure(xi) || is_call(quo_squash(xi))) {
+                               paste0(type, "_", i)
+                             } else {
+                               quo_text(xi)
+                             }
+                           }
   )
-
+  
   # confirm no dupes
   is_dupes <- duplicated(inferred_names)
   if (any(is_dupes)) {
     stop("You have more than one ", type, " named ", inferred_names[is_dupes])
   }
-
+  
   inferred_names
 }
 
