@@ -46,3 +46,15 @@ test_that("Describle Variable", {
     )
   )
 })
+
+
+test_that("Describle Variable", {
+  test <- data.frame(
+    d = seq(from = as.POSIXct("2018-01-01"),
+            to = as.POSIXct("2018-05-01"),
+            by = "days"))
+  # Different ways of bringing data into DD
+  pop1 <- declare_population(data = test)
+  dsgn <- pop1 + NULL 
+  expect_output(print(dsgn), "2018-01-01")
+})
